@@ -25,6 +25,16 @@ class User(Document):
         required=True,
         max_length=200
     )
+    country_code = StringField(
+        default='86',
+        required=True,
+        max_length=50,
+    )
+    mobile = StringField(
+        unique=True,
+        required=True,
+        max_length=200,
+    )
     username = StringField(
         required=True,
         max_length=200,
